Stock Product Location Module
#############################

The Stock Product Location Module adds on the product form a list of
preferred location by warehouse. This list is used when a supplier
shipment is received: the auto-generated Inventory Moves will use as
default destination the preferred locations associated to the current
warehouse.
